contracts\_lib\_py.templates.template\_manager module
=====================================================

.. automodule:: contracts_lib_py.templates.template_manager
   :members:
   :undoc-members:
   :show-inheritance:
